
service system/urandom {
	need = system/initial system/mountfs;
	
	script start = {
	[ -f /etc/default/rcS ] && . /etc/default/rcS

	. /lib/lsb/init-functions

	POOLSIZE=512
	if [ -f /proc/sys/kernel/random/poolsize ]
	then
		POOLSIZE="`/bin/cat /proc/sys/kernel/random/poolsize`"
	fi
	SAVEDFILE=/var/lib/urandom/random-seed
	log_begin_msg "Initializing random number generator..."
	# Load and then save $POOLSIZE bytes,
	# which is the size of the entropy pool
	if [ -f $SAVEDFILE ]
	then
		# Handle locally increased pool size
		SAVEDSIZE=`find $SAVEDFILE -printf "%s"`
		if [ $SAVEDSIZE -gt $POOLSIZE ]
		then
			[ -w /proc/sys/kernel/random/poolsize ] && echo $POOLSIZE > /proc/sys/kernel/random/poolsize
			POOLSIZE=$SAVEDSIZE
		fi
		/bin/cat $SAVEDFILE >/dev/urandom
	fi
	/bin/rm -f $SAVEDFILE
	umask 077
	/bin/dd if=/dev/urandom of=$SAVEDFILE \
		bs=$POOLSIZE count=1 >/dev/null 2>&1
	ES=$?
	umask 022
	exit 0
    }

    script stop = {
	echo "Saving random seed ..."
	# Carry a random seed from shut-down to start-up;
	# see documentation in linux/drivers/char/random.c
	umask 077
        /bin/dd if=/dev/urandom of=/var/lib/urandom/random-seed \
                bs=$POOLSIZE count=1 >/dev/null 2>&1 \
                || echo "urandom stop: failed."
        exit $?
    }

}
